/*
 * process, Distribution repositories and basic setup for Emmanuel Bigeon projects
 * Copyright (C) 2014-2018 E. Bigeon
 * mailto:emmanuel@bigeon.fr
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * gclc:fr.bigeon.gclc.proc.ThreadCommand.java
 * Created on: May 10, 2017
 */
package fr.bigeon.gclc.process;

/** Tasks are named runnable that can be interrupted.
 * <p>
 * Good practice for those objects include an absence of interaction with the
 * user (otherwise the user may not know from which running command comes
 * information and requests) and unicity of the object to have a coherent
 * control through the {@link #setRunning(boolean)} method.
 * <p>
 * Typical cases where such command can be useful is for an application that
 * does long computations.
 *
 * @author Emmanuel Bigeon */
public interface Task extends Runnable {
    /** Add a listener for this command end of execution
     *
     * @param listener the listener */
    void addInterruptionListener(InterruptionListener listener);

    /** Get the task name.
     * 
     * @return the task name */
    String getName();

    /** Test the running status of the task.
     * 
     * @return if the command is supposed to be running */
    boolean isRunning();

    /** Remove a listener of this command end of execution
     *
     * @param listener the listener */
    void rmInterruptionListener(InterruptionListener listener);

    /** Set the running state.
     * <p>
     * This method should be only called by external objects with the false
     * argument. Calling this method with true has unspecified behavior and
     * could do nothing as well as restart the command for example.
     *
     * @param running the running state */
    void setRunning(boolean running);
}
